#       _                                  _   _
#      | |                                | | | |
#   ___| |_ __  ___ __________ _ __  _   _| |_| |__   ___  _ __
#  / __| | '_ \/ __|_  /______| '_ \| | | | __| '_ \ / _ \| '_ \
# | (__| | |_) \__ \/ /       | |_) | |_| | |_| | | | (_) | | | |
#  \___|_| .__/|___/___|      | .__/ \__, |\__|_| |_|\___/|_| |_|
#        | |                  | |     __/ |
#        |_|                  |_|    |___/
__title__ = 'clpsz-python'
__description__ = 'clpsz\'s python utils'
__url__ = 'https://github.com/clpsz/clpsz-python'
__version__ = '0.0.7'
__author__ = 'Pengpeng Zuo'
__author_email__ = 'pengclpsz@gmail.com'
__license__ = 'NO-LICENCE'
__copyright__ = 'Copyright NO-COPYRIGHT'
